module.exports = defineTest({
	description: 'Deoptimize when __proto__ is used'
});
